;;; ej-theme.el --- Theme manager
;;; $Revision: 0.1

;; This file is not part of Emacs

;; Copyright (C) 2011 CyberDomovoy
;; Filename: ej-theme.el
;; Version: 0.1
;; Keywords:
;; Author: CyberDomovoy <cd@domovoynet.org>
;; Maintainer: CyberDomovoy <cd@domovoynet.org>
;; Created: 2011-01-09
;; Description: Theme manager
;; URL:
;; Compatibility: Emacs23


;; COPYRIGHT NOTICE
;;
;; This program is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 2 of the License, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
;; for more details. http://www.gnu.org/copyleft/gpl.html
;;

;;; Install:

;; Put this file on your Emacs-Lisp load path, add following into your
;; emacs startup file
;;
;;     (require 'ej-theme)
;;
;; Or use autoload and your Emacs starts faster, preferred method:
;;
;;      (autoload 'ej-theme-load "ej-theme" "" t)
;;
;; All symbols are prefixed with 'ej-'.
;;

;;; Commentary:

;;  TODO
;;

;;; Change Log:

;;; Code:

;;; .......................................................... require ...

(eval-when-compile (setq byte-compile-dynamic t))

(require 'custom)

(eval-and-compile
  ;; We really don't need to load full packages, so use these..
  ;;
  (autoload 'color-theme-make-snapshot "color-theme" "Make a snapshot of the current theme." t)
  (autoload 'color-theme-initialize    "color-theme" "Initialize color-theme."               t)
  )

;;; ............................................................ hooks ...

(defcustom ej-theme-load-hooks nil
  "*Hook run when package has been loaded."
  :type 'hook
  :group 'emacs-junkie)

;;; ........................................................... public ...
;;; User configurable variables

(defcustom ej-theme-default nil
  "*Default theme, if empty, use the colors defined when the package is loaded."
  :group 'emacs-junkie)

(defcustom ej-theme-day 'ej-theme-default
  "*Day theme"
  :group 'emacs-junkie)

(defcustom ej-theme-night 'color-theme-midnight
  "*Night theme"
  :group 'emacs-junkie)


;;; .......................................................... version ...

(defconst ej-theme-version (substring "$Revision: 0.1 $" 11 15)
  "Version number.")


;;; .......................................................... private ...
;;; Private, package's internal variables.
;; backup current color theme


;;; .......................................................... macros ...

;;; ........................................................... funcs ...

(defun ej-theme-current()
  "*Show current theme."
  
  (interactive)
  (message "Current theme is: %s" (symbol-name (car (car color-theme-history))))
  )

(defun ej-theme-random()
  "*Select a random theme."
  
  (interactive)
  (funcall (car (nth ( random (length color-themes)) color-themes)))
  (ej-theme-current)
  )

(defun ej-theme-load ()
  "*Load theme."

  (unless color-theme-initialized (color-theme-initialize))
  (funcall ej-theme-default)
  (ej-theme-current)
  )

(unless ej-theme-default
  (fset 'ej-theme-default (color-theme-make-snapshot))
  )

;; Configure color-theme
(setq color-theme-history-max-length 4)


(provide 'ej-theme)
(run-hooks 'ej-theme-load-hooks)

;;; ej-theme.el ends here


;;;; ej-theme.el

(require 'color-theme)



(provide 'ej-theme)
