;;; ej-utils.el --- Some usefull functions
;;; $Revision: 0.1

;; This file is not part of Emacs

;; Copyright (C) 2011 CyberDomovoy
;; Filename: ej-utils.el
;; Version: 0.1
;; Keywords: convenience frames
;; Author: CyberDomovoy <cd@domovoynet.org>
;; Maintainer: CyberDomovoy <cd@domovoynet.org>
;; Created: 2011-01-09
;; Description: Some usefull functions
;; URL:
;; Compatibility: Emacs23


;; COPYRIGHT NOTICE
;;
;; This program is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 2 of the License, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
;; for more details. http://www.gnu.org/copyleft/gpl.html
;;

;;; Install:

;; Put this file on your Emacs-Lisp load path, add following into your
;; emacs startup file
;;
;;     (require 'ej-utils)
;;
;; Or use autoload and your Emacs starts faster, preferred method:
;;
;;      (autoload 'ej-add-load-path-recursive "ej-utils" "" t)
;;      (autoload 'ej-color-distance          "ej-utils" "" t)
;;      (autoload 'ej-frame-x-active-window-p "ej-utils" "" t)
;;      (autoload 'ej-buffer-from-name        "ej-utils" "" t)
;;
;; All symbols are prefixed with 'ej-'.
;;

;;; Commentary:

;;  TODO

;;; Change Log:

;;; Code:

;;; .......................................................... require ...

(eval-when-compile (setq byte-compile-dynamic t))

(require 'custom)

;; from these packages we only use some functions...
;;(eval-and-compile
  ;; We really don't need to load full packages, so use these..
  ;;
;;)


;;; ............................................................ hooks ...

(defcustom ej-utils-load-hooks nil
  "*Hook run when package has been loaded."
  :type 'hook
  :group 'emacs-junkie)

;;; ........................................................... public ...
;;; User configurable variables


;;; .......................................................... version ...

(defconst ej-utils-version (substring "$Revision: 0.1 $" 11 15)
  "Version number.")


;;; .......................................................... private ...
;;; Private, package's internal variables.


;;; .......................................................... macros ...


;;; ........................................................... funcs ...

;;;###autoload
(defun ej-add-load-path-recursive (dir)
  "*Add `DIR' and its subdirs recursively to `load-path'."

  (let* (
	 (dir (expand-file-name dir))
	 (files (directory-files dir t "^[^.].+"))
	 (result t)
	 )
    (when (not (member dir load-path))
      (add-to-list 'load-path dir)
      )
    (dolist (file files result)
      (when (file-directory-p file)
	(setq result (ej-add-load-path-recursive file))
	)
      )
    )
  )

;;;###autoload
(defun ej-color-distance (color1 color2)
  "*Compute the difference between two colors.

Uses the weighted Euclidean distance formula proposed on
<http://www.compuphase.com/cmetric.htm>.
Remember that every component for the formula is in the range of 0-xFF
and `color-values' will return a range of 0-FFFF.  Thus, divide everything
by 256. This also helps preventing integer overflow.
Argument COLOR1 First color.
Argument COLOR2 Second color."
  
  (let* (
         (dr (/ (- (nth 0 (color-values color1))
		   (nth 0 (color-values color2))) 256))
	 (dg (/ (- (nth 1 (color-values color1))
		   (nth 1 (color-values color2))) 256))
	 (db (/ (- (nth 2 (color-values color1))
		   (nth 2 (color-values color2))) 256))
	 (red-mean (/ (+ (nth 0 (color-values color1))
			 (nth 0 (color-values color2)))
		      2 256)))
    (sqrt (+ (ash (* (+ 512 red-mean) dr dr) -8)
	     (* 4 dg dg)
	     (ash (* (- 767 red-mean) dr dr) -8)))
    )
  )

(defun ej-x-active-window ()
  "Return the window ID of the current active window in X.

Uses the _NET_ACTIVE_WINDOW of the root window set by the
window-manager, or nil if not able to."

  (let (x-active-window)
    (when (eq (window-system) 'x)
      (setq x-active-window (x-window-property "_NET_ACTIVE_WINDOW" nil "WINDOW" 0 nil t))
      (string-to-number (format "%x00%x" (car x-active-window) (cdr x-active-window)) 16)
      )
    )
  )

(defun ej-frame-outer-window (frame)
  "Return the frame outer-window-id property, or nil if FRAME not of the correct type."

  (when (framep frame)
    (string-to-number (frame-parameter frame 'outer-window-id))
    )
  )

;;;###autoload
(defun ej-frame-x-active-window-p (frame)
  "*Check if FRAME is in the X active window, return t if FRAME has focus or nil if not."
  
  (when (and
         (framep frame)
         (eq (ej-frame-outer-window frame) (ej-x-active-window))
         )
    t)
  )

;;;###autoload
(defun ej-buffer-from-name (name)
  "*Find buffer that start with NAME.

Use get-buffer!"

  (get-buffer name)
  )


(provide 'ej-utils)
(run-hooks 'ej-utils-load-hooks)

;;; ej-utils.el ends here