;;; emacs-junkie.el --- Setup autoloads and default keybindings for emacs-junkie packages
;;; $Revision: 0.1

;; This file is not part of Emacs

;; Copyright (C) 2011 CyberDomovoy
;; Filename: emacs-junkie.el
;; Version: 0.1
;; Keywords:
;; Author: CyberDomovoy <cd@domovoynet.org>
;; Maintainer: CyberDomovoy <cd@domovoynet.org>
;; Created: 2011-01-09
;; Description: Setup autoloads and default keybindings for emacs-junkie packages
;; URL:
;; Compatibility: Emacs23


;; COPYRIGHT NOTICE
;;
;; This program is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 2 of the License, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
;; for more details. http://www.gnu.org/copyleft/gpl.html
;;

;;; Install:

;; Put this file on your Emacs-Lisp load path, add following into your
;; emacs startup file
;;
;;     (require 'emacs-junkie)
;;
;; All symbols are prefixed with 'ej-'.
;;

;;; Commentary:

;;  TODO
;;
;;     Helper for elisp editing (lm-verify, checkdoc, elint)
;;     RSS reader <http://www.emacswiki.org/emacs-en/GnusRss>
;;     NetworkManager <http://www.emacswiki.org/emacs-en/GnusNetworkManager>
;;     Check TinyTools, seems to have a lot of interesting stuff <http://www.nongnu.org/emacs-tiny-tools/>
;;     Use good coding standards <http://www.nongnu.org/emacs-tiny-tools/>

;;; Change Log:

;;; Code:

;;; .......................................................... require ...

(eval-when-compile (setq byte-compile-dynamic t))

;; Add the package directory to load-path
(let
    (
     (my-dir (expand-file-name (file-name-directory load-file-name)))
     )
  (when (not (member my-dir load-path))
    (add-to-list 'load-path my-dir)
    )
  )

(require 'custom)

(eval-and-compile
  ;; We really don't need to load full packages, so use these..
  ;;
  ;; ej-utils
  (autoload 'ej-add-load-path-recursive  "ej-utils" "Add a directory to load-path recursively." t)
;;  (autoload 'ej-color-distance           "ej-utils" "Compute the difference between two colors." t)
;;  (autoload 'ej-frame-x-active-window-p  "ej-utils" "Check if a frame is in the active window."  t)
;;  (autoload 'ej-buffer-from-name         "ej-utils" "Find buffer by name."                       t)
  ;; ej-init
  (autoload 'ej-init                     "ej-init"  "init.d style startup."                     t)
  ;; ej-term
  (autoload 'ej-term                     "ej-term"  "ANSI terminal emulator."                   t)
  ;; ej-theme
  (autoload 'ej-theme-load               "ej-theme" "Load color theme."                         t)
  ;; ej-irc
;;  (autoload 'ej-irc                      "ej-irc"   "Start irc."                                 t)
;;  (autoload 'ej-irc-auto-reconnect-start "ej-irc"   "Start irc auto-reconnect."                  t)
;;  (autoload 'ej-irc-auto-reconnect-stop  "ej-irc"   "Stop irc auto-reconnect."                   t)
  ;; ej-mua
;;  (autoload 'ej-mua                      "ej-mua"   "Start mua."                                 t)
;;  (autoload 'ej-mua-auto-fetch-start     "ej-mua"   "Start mua auto-fetch."                      t)
;;  (autoload 'ej-mua-auto-fetch-stop      "ej-mua"   "Stop mua auto-fetch."                       t)
  )

;;; ............................................................ hooks ...

(defcustom ej-load-hooks nil
  "*Hook run when package has been loaded."
  :type 'hook
  :group 'emacs-junkie)

;;; ........................................................... public ...
;;; User configurable variables

;;; .......................................................... version ...

(defconst ej-version (substring "$Revision: 0.1 $" 11 15)
  "Version number.")


;;; .......................................................... private ...
;;; Private, package's internal variables.


;;; .......................................................... macros ...

;;; ........................................................... funcs ...


(provide 'emacs-junkie)
(provide 'ej)
(run-hooks 'ej-load-hooks)

;;; emacs-junkie.el ends here

;;(require 'ej-sudo)
;;(require 'ej-bufferlist)
;;(require 'ej-irc)
;;(require 'ej-mua)
